@@ -15,7 +15,7 @@
 #'
 #' Main functions used per database:
 #' - MongoDB: find() in [mongolite::mongo()]
-#' - SQLite: SQL query using `json_tree()`
+#' - SQLite: SQL query using built-in `json_tree()`
 #' - Elasticsearch: [elastic::Search()]
 #' - CouchDB: [sofa::db_query()]
 #' - PostgreSQL: SQL query using built-in `jsonb_build_object()`
@@ -727,7 +727,7 @@ docdb_query.src_duckdb <- function(src, key, query, ...) {
   statement <- paste0(statement, "; ")
 
   # handle query terms with json
-  jqrSubsetFunction <- ""
+  jqrSubsetFunction <- NULL
   if (querySql[[1]][1] != "" &&
       any(sapply(querySql, "[[", 3) == "json")) {
     jqrSubsetFunction <- paste0(
